@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Phrasebook;
-BEGIN {
-  $Net::CLI::Interact::Phrasebook::VERSION = '1.112610';
+{
+  $Net::CLI::Interact::Phrasebook::VERSION = '1.113600';
 }
 
 use Moose;
@@ -50,14 +50,19 @@ has '_prompt' => (
 
 sub prompt {
     my ($self, $name) = @_;
-    confess "missing prompt argument!" unless defined $name;
-    confess "unknown prompt [$name]"
-        unless length $name and exists $self->_prompt->{$name};
+    confess "unknown prompt [$name]" unless $self->has_prompt($name);
     return $self->_prompt->{$name};
 }
 
 sub prompt_names { return keys %{ (shift)->_prompt } }
 
+sub has_prompt {
+    my ($self, $name) = @_;
+    confess "missing prompt name!"
+        unless defined $name and length $name;
+    return exists $self->_prompt->{$name};
+}
+
 has '_macro' => (
     is => 'ro',
     isa => 'HashRef[Net::CLI::Interact::ActionSet]',
@@ -67,14 +72,19 @@ has '_macro' => (
 
 sub macro {
     my ($self, $name) = @_;
-    confess "missing macro argument!" unless defined $name;
-    confess "unknown macro [$name]"
-        unless length $name and exists $self->_macro->{$name};
+    confess "unknown macro [$name]" unless $self->has_macro($name);
     return $self->_macro->{$name};
 }
 
 sub macro_names { return keys %{ (shift)->_macro } }
 
+sub has_macro {
+    my ($self, $name) = @_;
+    confess "missing macro name!"
+        unless defined $name and length $name;
+    return exists $self->_macro->{$name};
+}
+
 # matches which are prompt names are resolved to RegexpRefs
 # and regexp provided by the user are inflated into RegexpRefs
 sub _resolve_matches {
@@ -243,7 +253,7 @@ Net::CLI::Interact::Phrasebook - Load command phrasebooks from a Library
 
 =head1 VERSION
 
-version 1.112610
+version 1.113600
 
 =head1 DESCRIPTION
 
@@ -339,6 +349,10 @@ Returns the Prompt associated to the given C<$name>, or throws an exception if
 no such prompt can be found. The returned object is an instance of
 L<Net::CLI::Interact::ActionSet>.
 
+=head2 has_prompt( $name )
+
+Returns true if a prompt of the given C<$name> exists in the loaded phrasebooks.
+
 =head2 prompt_names
 
 Returns a list of the names of the current loaded Prompts.
@@ -349,6 +363,10 @@ Returns the Macro associated to the given C<$name>, or throws an exception if
 no such macro can be found. The returned object is an instance of
 L<Net::CLI::Interact::ActionSet>.
 
+=head2 has_macro( $name )
+
+Returns true if a macro of the given C<$name> exists in the loaded phrasebooks.
+
 =head2 macro_names
 
 Returns a list of the names of the current loaded Macros.
